/*******************************************************************************
 * Licensed Materials - Property of IBM
 * Copyright IBM Corp. 2009, 2010.  All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("sketcher.rmps.properties.SketchLinksSection");

dojo.require("dijit._Widget");
dojo.require("dojo.i18n");

dojo.require("rmps.app.core.util");

dojo.require("jazz.ui.StyledTable");
dojo.require("jazz.ui.ResourceLink");

dojo.requireLocalization("sketcher.rmps.properties", "SketchLinksSectionMessages");
	
var messages = dojo.i18n.getLocalization("sketcher.rmps.properties", "SketchLinksSectionMessages");

dojo.declare("sketcher.rmps.properties.SketchLinksSection", dijit._Widget, {
	
	"class": "sketcher-rmps-properties-sketchLinksSection",
	
	// mixin properties
	/*
	 * sketchlinks: [
	 *                {
	 *                    category: "",
	 *                    value: { // or array
	 *                               label: "",
	 *                               uri: "" || null
	 *                           }
	 *                }
	 *            ]
	 */
	tableData: null,
	
	// private properties
	_table: null,
	
	postCreate: function() {
		this.containerNode = this.domNode;
		
		var columns = [
			{
				label: messages.column_property,
			},
			{
				label: messages.column_value,
			}
		];
		
		this._table = new jazz.ui.StyledTable({
			columns: columns	
		});
		this._table.containerNode = this._table.domNode;
		
		if (this.tableData) {
			for (var i = 0, data; data = this.tableData[i]; ++i) {
				this._table.tbody.appendChild(this._createLinkRow(data));
			}
		}
		
		this.domNode.appendChild(this._table.domNode);
	},
	
	_createLinkRow: function(rowData) {
		var tr = dojo.create("tr");
		var propertyCell = dojo.create("td", {"class": "label"}, tr);
		var valueCell = dojo.create("td", {"class": "value"}, tr);
		
		propertyCell.appendChild(dojo.doc.createTextNode(rowData.label));
		
		var value = rowData.value;
		if (value) {
			if (dojo.isArray(value)) {
				if (value.length > 0) {
					for (var i = 0; i < value.length; ++i) {
						if (i != 0) {
							valueCell.appendChild(dojo.create("br"));
						}
						this._populateValueCell(valueCell, value[i]);
					}
				} else {
					valueCell.innerHTML = "&nbsp;";
				}
			} else {
				this._populateValueCell(valueCell, value);
			}
		} else {
			valueCell.innerHTML = "&nbsp;";
		}
		
		return tr;
	},

	_populateValueCell: function(valueCell, value) {
		if (value.dmuri) {
			var presentationUri = rmps.app.core.util.getViewResourceUri(value.dmuri);
			var linkNode = dojo.create("a", {href: presentationUri}, valueCell);		
			linkNode.appendChild(dojo.doc.createTextNode(value.label));
            this.connect(linkNode, "onclick", "close");
			
			new jazz.ui.ResourceLink({
						retainLinkText: true, 
						lazyFetch: true, 
						uri: net.jazz.ajax._contextRoot + "/rendering?resourceUri=" +  encodeURIComponent(value.dmuri), 
						presentationUri: presentationUri
					}, linkNode);
			
		} else if (value.otheruri) {
			var linkNode = dojo.create("a", { href: value.otheruri, target: "_blank" }, valueCell);
			linkNode.appendChild(dojo.doc.createTextNode(value.label));
			
		} else if (value.label != null && value.label.length > 0) {
			valueCell.appendChild(dojo.doc.createTextNode(value.label));
			
		} else {
			valueCell.innerHTML += "&nbsp;";
			return false;
		}
		return true;
	},
	
	
	close: function(){
		var popup= this.domNode.parentNode.parentNode.parentNode.parentNode.parentNode.parentNode;
		popup.style.display = "none";
		popup.style.visibility = "hidden";
		this.destroyRecursive(); 
	},
	
	
});

})();